sets
    i "motor domain" /1*15/
    ii "variables domain" /1*6/
;

parameters
  n              /10/
  lgap            /7.0e-1/
  poles          /2/
  m               /1/
  voltag         /115.0/
  resist        /1.69e-3/
  dcopper       /.896/
  dsteel        /.785/
  T(i)     /1 0.05,2 0.1, 3 0.125, 4 0.15, 5  0.2, 6   0.25, 7 0.275, 8 0.3, 9 0.325, 10 0.35, 11 0.375, 12 0.4, 13 0.425, 14 0.45 , 15 0.5 /
  p        /300.0/
  maxh        /5000/
  minh       /3000/
  maxmass     /2.0/
  minmass     /0.2/
  mineta      /0.5/
  muo
  pi
  mur   / 1000/
  lmin /10/
  lmax /40/
  mro
  x(ii,i)
  torque
  Total
;

pi=2*arctan(inf); muo=4.0e-4*pi; mro=4.0e-4*pi;

positive variables

  awf      "cross-sectional area of the field wire [0.1,1.0]mm^2"
  radius   "radius of the motor [10,50]mm"
  thick    "thickness of the stator [1,10]mm"
  currnt   "current drawn (state variable) [1,6]amp"
*;
*integer variables
  narm    "number of windings on the armature [100,1500]"
  nfield  "number of windings on the field [1,500]"
;


equations
maxm   "maximum mass of each motor"
minm   "maximum mass of each motor"
mineff "minimum efficiency of each motor"
maxeff
lo1
up1
lo2
up2
sat1   "maximum H"
sat2   "maximum H"
feas  "feasiblity constraint"
obj       "objective function"
;

free variables totobj;


* variables bounds

awf.lo=0.1;        awf.up=1.0;
radius.lo=1;       radius.up=5;
thick.lo=0.1;      thick.up=1.0;
currnt.lo=1.0;     currnt.up=6.0;
narm.lo=200;       narm.up=1500;
nfield.lo=50;      nfield.up=200;



*awf1('1')= 0.295;      awf1('2')=0.296 ;       awf1('3')=0.395;     awf1('4')=0.295;     awf1('5')=0.296;
*thick1('1')= 0.460;    thick1('2')= 0.566;     thick1('3')= 0.59;   thick1('4')=0.624;   thick1('5')=0.665;
*currnt1('1')= 2.965;   currnt1('2')=3.149 ;    currnt1('3')=3.236;  currnt1('4')=4.320;  currnt1('5')=3.494;
*radius1('1')=1.7688;   radius1('2')= 2.056;    radius1('3')=2.139;  radius1('4')=2.222;  radius1('5')=2.339;
*narm1('1')=762   ;     narm1('2')=824   ;      narm1('3')=889  ;    narm1('4')=945  ;    narm1('5')=1037 ;
*nfield1('1')= 75   ;   nfield1('2')= 102   ;    nfield1('3')= 83  ;  nfield1('4')= 84  ;  nfield1('5')= 94  ;


*awf1('6')=0.295;       awf1('7')=0.296;        awf1('8')=0.295;     awf1('9')=0.296;     awf1('10')=0.295;
*thick1('6')=0.712;     thick1('7')=0.748;      thick1('8')=2.587;   thick1('9')=2.652;   thick1('10')=2.715;
*currnt1('6')=3.664;    currnt1('7')=3.842;     currnt1('8')=0.759;  currnt1('9')=0.786;  currnt1('10')=0.804;
*radius1('6')=2.454;    radius1('7')=2.543;     radius1('8')=4.055;  radius1('9')=4.262;  radius1('10')=4.794;
*narm1('6')=1110 ;      narm1('7')=1169 ;       narm1('8')=1215 ;    narm1('9')=1254 ;    narm1('10')=1301 ;
*nfield1('6')=84   ;    nfield1('7')=83   ;     nfield1('8')=80   ;  nfield1('9')=78   ;  nfield1('10')=71   ;



sat1  ..   2.0*nfield*currnt/(5.1416*radius-0.4292*thick)=l=maxh/100;
sat2  ..   2.0*nfield*currnt/(5.1416*radius-0.4292*thick)=g=minh/100;


feas ..   radius=g=thick+200*lgap*0.001;

up2 ..    1.0e-3*lmax*currnt**2*narm*nfield=g=(torque*pi*pi*(radius+0.5*thick)/(2*mro*thick)+torque*pi/mro+100*torque*pi*lgap/
          (muo*(radius-thick-0.1*lgap)));

lo2 ..    1.0e-3*lmin*currnt**2*narm*nfield=l=(torque*pi*pi*(radius+0.5*thick)/(2*mro*thick)+torque*pi/mro+100*torque*pi*lgap/
          (muo*(radius-thick-0.1*lgap)));

lo1 ..    (voltag*currnt-p-2*currnt)*0.1-10*currnt**2*0.1/awf*2*resist*nfield*(2*(torque*pi*pi*(radius+0.5*thick)
             /(2*mro*thick*currnt**2*narm*nfield)+torque*pi/(mro*currnt**2*narm*nfield)+100*torque*pi*lgap/
             (currnt**2*narm*nfield*muo*(radius-thick-0.1*lgap)))+0.04*(radius-thick))=l=10*currnt**2*
             resist*narm*(2*(torque*pi*pi*(radius+0.5*thick)/(2*mro*thick*currnt**2*narm*nfield)+torque*pi/
             (mro*currnt**2*narm*nfield)+100*torque*pi*lgap/(currnt**2*narm*nfield*muo*(radius-thick-0.1*lgap)))+0.04*
             (radius-thick-lgap*0.1));


up1 ..    (voltag*currnt-p-2*currnt)-10*currnt**2/awf*2*resist*nfield*(2*(torque*pi*pi*(radius+0.5*thick)
             /(2*mro*thick*currnt**2*narm*nfield)+torque*pi/(mro*currnt**2*narm*nfield)+100*torque*pi*lgap/
             (currnt**2*narm*nfield*muo*(radius-thick-0.1*lgap)))+0.04*(radius-thick))=g=10*currnt**2*
              resist*narm*(2*(torque*pi*pi*(radius+0.5*thick)/(2*mro*thick*currnt**2*narm*nfield)+torque*pi/
             (mro*currnt**2*narm*nfield)+100*torque*pi*lgap/(currnt**2*narm*nfield*muo*(radius-thick-0.1*lgap)))+0.04*
             (radius-thick-lgap*0.1));



maxm .. (torque*pi**2*dsteel/currnt**2*(2*radius*thick-thick**2)*(pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-lgap*0.1))))
       +(torque*pi**2*dsteel/currnt**2*(radius-thick-lgap*0.1)**2*(pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-lgap*0.1))))
       +.02*dcopper/currnt**2*(narm*((1.0/((voltag*currnt-p-2*currnt)-10*currnt**2/awf*2*resist*nfield*(2*(torque*pi*pi*(radius+0.5*thick)
       /(2*mro*thick*currnt**2*narm*nfield)+torque*pi/(mro*currnt**2*narm*nfield)+100*torque*pi*lgap/(currnt**2*narm*nfield*muo*(radius-thick-
       0.1*lgap)))+0.04*(radius-thick)))*10*currnt**2*resist*narm*(2*(torque*pi*pi*(radius+0.5*thick)/(2*mro*thick*currnt**2*narm*nfield)+torque*pi/
       (mro*currnt**2*narm*nfield)+100*torque*pi*lgap/(currnt**2*narm*nfield*muo*(radius-thick-0.1*lgap)))+0.04*(radius-thick-lgap*0.1))))*((torque*pi*
       (pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-0.1*lgap))))+0.02*(radius-thick-0.1*lgap)*narm*nfield*currnt**2)+nfield*
       awf*(2*(torque*pi*(pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-0.1*lgap))))+0.04*narm*nfield*currnt**2*(radius-thick)))
        =l=maxmass*narm*nfield;



minm .. (torque*pi**2*dsteel/currnt**2*(2*radius*thick-thick**2)*(pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-lgap*0.1))))
       +(torque*pi**2*dsteel/currnt**2*(radius-thick-lgap*0.1)**2*(pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-lgap*0.1))))
       +.02*dcopper/currnt**2*(narm*((1.0/((voltag*currnt-p-2*currnt)-10*currnt**2/awf*2*resist*nfield*(2*(torque*pi*pi*(radius+0.5*thick)
       /(2*mro*thick*currnt**2*narm*nfield)+torque*pi/(mro*currnt**2*narm*nfield)+100*torque*pi*lgap/(currnt**2*narm*nfield*muo*(radius-thick-
       0.1*lgap)))+0.04*(radius-thick)))*10*currnt**2*resist*narm*(2*(torque*pi*pi*(radius+0.5*thick)/(2*mro*thick*currnt**2*narm*nfield)+torque*pi/
       (mro*currnt**2*narm*nfield)+100*torque*pi*lgap/(currnt**2*narm*nfield*muo*(radius-thick-0.1*lgap)))+0.04*(radius-thick-lgap*0.1))))*((torque*pi*
       (pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-0.1*lgap))))+0.02*(radius-thick-0.1*lgap)*narm*nfield*currnt**2)+nfield*
       awf*(2*(torque*pi*(pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-0.1*lgap))))+0.04*narm*nfield*currnt**2*(radius-thick)))
        =g=minmass*narm*nfield;


mineff .. p/(voltag * currnt)=g=mineta;
maxeff .. p/(voltag * currnt)=l=1.0;



obj ..   narm.up*totobj=e=0.5*(narm.up-p*narm.up/(voltag*currnt))+0.5*(narm.up/(maxmass*nfield*narm)*((torque*pi**2*dsteel/currnt**2*(radius**2
         +0.01*lgap**2+0.2*thick*lgap-0.2*radius*lgap)*(pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-lgap*0.1))))+.02*dcopper/
         currnt**2*(narm*((1.0/((voltag*currnt-p-2*currnt)-10*currnt**2/awf*2*resist*nfield*(2*(torque*pi*pi*(radius+0.5*thick)/(2*mro*thick*currnt**2*
         narm*nfield)+torque*pi/(mro*currnt**2*narm*nfield)+100*torque*pi*lgap/(currnt**2*narm*nfield*muo*(radius-thick-0.1*lgap)))+0.04*(radius-thick)))
         *10*currnt**2*resist*narm*(2*(torque*pi*pi*(radius+0.5*thick)/(2*mro*thick*currnt**2*narm*nfield)+torque*pi/(mro*currnt**2*narm*nfield)+100*
         torque*pi*lgap/(currnt**2*narm*nfield*muo*(radius-thick-0.1*lgap)))+0.04*(radius-thick-lgap*0.1))))*((torque*pi*(pi*(2*radius+thick)/(4*mro*
         thick)+1/(mro)+100*lgap/(muo*(radius-thick-0.1*lgap))))+0.02*(radius-thick-0.1*lgap)*narm*nfield*currnt**2)+nfield*awf*(2*(torque*
         pi*(pi*(2*radius+thick)/(4*mro*thick)+1/(mro)+100*lgap/(muo*(radius-thick-0.1*lgap))))+0.04*narm*nfield*currnt**2*(radius-thick)))));

model motor /all/ ;
     motor.optfile=1;
$onecho > baron.opt
    epsr 0.0001
    maxtime=1200000
    nlpsol=4
    nlpdolin=0
$offecho
option nlp=baron;
Total=0.0;
loop (i,
     torque=T(i);
     solve motor using nlp minimizing totobj;
     x('1',i)=awf.l;
    x('2',i)=radius.l;
    x('3',i)=thick.l;
    x('4',i)=currnt.l;
    x('5',i)=narm.l;
    x('6',i)=nfield.l;
    Total=Total+totobj.l;

);

display x,Total;