$offlisting
$offsymxref
$offsymlist
$offuelxref

set   i  "motor domain" /1*2/
      k "variable domain" /1*6/
      kk "platform domain" /1*2/;

alias(i,j);
set ij(i,j) /1.2/;

parameters
  lgap            /7.0e-1/
  poles          /2/
  m               /1/
  voltag         /115.0/
  resist        /1.69e-3/
  dcopper       /.896/
  dsteel        /.785/
  torque(i)     /1 0.5, 2 0.1/
  p        /300.0/
  maxh        /5000/
  minh       /3000/
  maxmass     /2.0/
  minmass     /0.2/
  mineta      /0.4/
  muo
  pi
  mur   / 1000/
  lmin /10/
  lmax /40/
  mro
  landa(kk),g(kk),alpha,oldobj,xf(k,i),final
  fupper /0.8/
;
 scalar ii;
pi= 2*arctan(inf);   muo=4.0e-4*pi; mro=4.0e-4*pi;

positive variables

  awf(i)      "cross-sectional area of the field wire [0.1,1.0]mm^2"
  radius(i)   "radius of the motor [10,50]mm"
  thick(i)    "thickness of the stator [1,10]mm"
  currnt(i)   "current drawn (state variable) [1,6]amp"
  narm(i)    "number of windings on the armature [100,1500]"
  nfield(i)  "number of windings on the field [1,500]"

;

free variables
totobj "objective function"
;

equations
  maxm(i)   "maximum mass of each motor"
  minm(i)   "maximum mass of each motor"
  mineff(i) "minimum efficiency of each motor"
  maxeff(i)
  lo1(i)
  up1(i)
  lo2(i)
  up2(i)
  sat1(i)   "maximum H"
  sat2(i)   "maximum H"
   feas(i)  "feasiblity constraint"
   obj       "objective function"
;
  alpha=1.0;  oldobj=0.0;

* variables bounds

awf.lo(i)=0.1;        awf.up(i)=1.;
radius.lo(i)=1;       radius.up(i)=5;
thick.lo(i)=0.2;      thick.up(i)=1.0;
currnt.lo(i)=2.0;      currnt.up(i)=6.0;
narm.lo(i)=300;        narm.up(i)=1500;
nfield.lo(i)=60;        nfield.up(i)=500;


awf.l('1')= 0.295;      awf.l('2')=0.295 ;
radius.l('1')=2.217;   radius.l('2')= 1.762;
thick.l('1')= 0.621;    thick.l('2')= 0.456;
currnt.l('1')= 3.322;   currnt.l('2')=2.966 ;
narm.l('1')=945   ;     narm.l('2')=642   ;
nfield.l('1')= 84   ;   nfield.l('2')= 75  ;

sat1(i)  ..   2.0*nfield(i)*currnt(i)/(5.1416*radius(i)-0.4292*thick(i))=l=maxh/100;
sat2(i)  ..   2.0*nfield(i)*currnt(i)/(5.1416*radius(i)-0.4292*thick(i))=g=minh/100;


feas(i) ..   radius(i)=g=thick(i)+200*lgap*0.001;

up2(i) ..  1.0e-3*lmax*currnt(i)**2*narm(i)*nfield(i)=g=(torque(i)*pi*pi*(radius(i)+
           0.5*thick(i))/(2*mro*thick(i))+torque(i)*pi/mro+100*torque(i)*pi*lgap/(muo*(radius(i)-thick(i)-0.1*lgap)));

lo2(i) ..  1.0e-3*lmin*currnt(i)**2*narm(i)*nfield(i)=l=(torque(i)*pi*pi*(radius(i)+
           0.5*thick(i))/(2*mro*thick(i))+torque(i)*pi/mro+100*torque(i)*pi*lgap/(muo*(radius(i)-thick(i)-0.1*lgap)));




lo1(i) ..    (voltag*currnt(i)-p-2*currnt(i))*0.1-10*currnt(i)**2*0.1/awf(i)*2*resist*nfield(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*(radius(i)-thick(i)))=l=10*currnt(i)**2*
             resist*narm(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*
             (radius(i)-thick(i)-lgap*0.1));


up1(i) ..    (voltag*currnt(i)-p-2*currnt(i))-10*currnt(i)**2/awf(i)*2*resist*nfield(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*(radius(i)-thick(i)))=g=10*currnt(i)**2*
              resist*narm(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*
             (radius(i)-thick(i)-lgap*0.1));


maxm(i) ..
 ((torque(i)*pi**2*dsteel/currnt(i)**2*(2*radius(i)*thick(i)-thick(i)**2)*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))+
 1/(mro)+100*lgap/(muo*(radius(i)-thick(i)-lgap*0.1))))

 +(torque(i)*pi**2*dsteel/currnt(i)**2*(radius(i)-thick(i)-lgap*0.1)**2*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))
 +1/(mro)+100*lgap/(muo*(radius(i)-thick(i)-lgap*0.1))))
  +.02*dcopper/currnt(i)**2*(narm(i)*((1.0/((voltag*currnt(i)-p-2*currnt(i))-10*currnt(i)**2/awf(i)*2*resist*nfield(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*(radius(i)-thick(i))))*10*currnt(i)**2*
             resist*narm(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*
             (radius(i)-thick(i)-lgap*0.1))))*((torque(i)*pi*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius(i)-thick(i)-0.1*lgap))))+0.02*(radius(i)-thick(i)-0.1*lgap)*narm(i)*nfield(i)*currnt(i)**2)+nfield(i)*awf(i)*(2*(torque(i)*
pi*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius(i)-thick(i)-0.1*lgap))))+0.04*narm(i)*nfield(i)*currnt(i)**2*(radius(i)-thick(i)))))=l=maxmass*narm(i)*nfield(i);



minm(i) ..
 (((torque(i)*pi**2*dsteel/currnt(i)**2*(2*radius(i)*thick(i)-thick(i)**2)*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))+
 1/(mro)+100*lgap/(muo*(radius(i)-thick(i)-lgap*0.1))))

 +(torque(i)*pi**2*dsteel/currnt(i)**2*(radius(i)-thick(i)-lgap*0.1)**2*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))
 +1/(mro)+100*lgap/(muo*(radius(i)-thick(i)-lgap*0.1))))
  +.02*dcopper/currnt(i)**2*(narm(i)*((1.0/((voltag*currnt(i)-p-2*currnt(i))-10*currnt(i)**2/awf(i)*2*resist*nfield(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*(radius(i)-thick(i))))*10*currnt(i)**2*
             resist*narm(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*
             (radius(i)-thick(i)-lgap*0.1))))*((torque(i)*pi*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius(i)-thick(i)-0.1*lgap))))+0.02*(radius(i)-thick(i)-0.1*lgap)*narm(i)*nfield(i)*currnt(i)**2)+nfield(i)*awf(i)*(2*(torque(i)*
pi*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius(i)-thick(i)-0.1*lgap))))+0.04*narm(i)*nfield(i)*currnt(i)**2*(radius(i)-thick(i))))))=g=minmass*narm(i)*nfield(i);



mineff(i) .. p/(voltag * currnt(i))=g=mineta;

maxeff(i) .. p/(voltag * currnt(i))=l=1.0;


obj ..   narm.up('1')*totobj=e=sum(i,0.5*(narm.up(i)-p*narm.up(i)/(voltag * currnt(i)))+0.5*(narm.up(i)/
         (maxmass*nfield(i)*narm(i))*((torque(i)*pi**2*dsteel/currnt(i)**2*(radius(i)**2+0.01*lgap**2+0.2*thick(i)*lgap-0.2*radius(i)*lgap)*(pi*(2*radius(i)+thick(i))/
         (4*mro*thick(i))+1/(mro)+100*lgap/(muo*(radius(i)-thick(i)-lgap*0.1))))

  +.02*dcopper/currnt(i)**2*(narm(i)*((1.0/((voltag*currnt(i)-p-2*currnt(i))-10*currnt(i)**2/awf(i)*2*resist*nfield(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*(radius(i)-thick(i))))*10*currnt(i)**2*
             resist*narm(i)*(2*(torque(i)*pi*pi*(radius(i)+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield(i))+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield(i))+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield(i)*muo*(radius(i)-thick(i)-0.1*lgap)))+0.04*
             (radius(i)-thick(i)-lgap*0.1))))*((torque(i)*pi*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius(i)-thick(i)-0.1*lgap))))+0.02*(radius(i)-thick(i)-0.1*lgap)*narm(i)*nfield(i)*currnt(i)**2)+nfield(i)*awf(i)*(2*(torque(i)*
pi*(pi*(2*radius(i)+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius(i)-thick(i)-0.1*lgap))))+0.04*narm(i)*nfield(i)*currnt(i)**2*(radius(i)-thick(i)))))))
+0.1*narm.up('1')*
    (landa('1')*(radius('1')-radius('2'))/(radius.up('1')-radius.lo('1'))
    +landa('2')*(nfield('1')-nfield('2'))/(nfield.up('1')-nfield.lo('1'))
);


model motor /all/ ;
motor.optfile=1;
$onecho > baron.opt
epsr 0.0001
maxtime=1200000
nlpsol=4
nlpdolin=0
numsol=10
$offecho
option minlp=baron;
landa(kk)=0.0; final=-10000
for (ii=1 to 50,

solve motor using minlp minimizing totobj;
if (oldobj>totobj.l,
   alpha=alpha/2;
else
   alpha=0.5;
);

 xf('1',i)=awf.l(i);
 xf('2',i)=radius.l(i);
 xf('3',i)=thick.l(i);
 xf('4',i)=currnt.l(i);
 xf('5',i)=narm.l(i);
 xf('6',i)=nfield.l(i);

g('1')=(radius.l('1')-radius.l('2'))/(radius.up('1')-radius.lo('1'));
g('2')=(nfield.l('1')-nfield.l('2'))/(nfield.up('1')-nfield.lo('1')) ;
if (totobj.l>final,
   final=totobj.l;
);

*landa(kk)=landa(kk)+(alpha*(fupper-totobj.l)/power(g(kk),2)*g(kk))$(abs(g(kk))>1e-4);
landa(kk)=landa(kk)+alpha*g(kk)/sqrt(power(g(kk),2));

oldobj=totobj.l;
display xf, g,landa, totobj.l
);

display final;