$offlisting
$offsymxref
$offsymlist
$offuelxref

set   i  "motor domain" /1*5/
      k "variable domain" /1*6/;


parameters
  lgap            /7.0e-1/
  poles          /2/
  m               /1/
  voltag         /115.0/
  resist        /1.69e-3/
  dcopper       /.896/
  dsteel        /.785/
  torque(i)     /1 0.5,2 0.1, 3 0.2, 4 0.3, 5 0.4/
  p        /300.0/
  maxh        /5000/
  minh       /3000/
  maxmass     /2.0/
  minmass     /0.2/
  mineta      /0.4/
  muo
  pi
  mur   / 1000/
  lmin /10/
  lmax /40/
  mro
  ;
 scalar ii;
pi= 2*arctan(inf);   muo=4.0e-4*pi; mro=4.0e-4*pi;

positive variables

  awf(i)      "cross-sectional area of the field wire [0.1,1.0]mm^2"
  radius   "radius of the motor [10,50]mm"
  thick(i)    "thickness of the stator [1,10]mm"
  currnt(i)   "current drawn (state variable) [1,6]amp"
  narm(i)    "number of windings on the armature [100,1500]"
  nfield  "number of windings on the field [1,500]"

;

free variables
totobj "objective function"
;

equations
  maxm(i)   "maximum mass of each motor"
  minm(i)   "maximum mass of each motor"
  mineff(i) "minimum efficiency of each motor"
  maxeff(i)
  lo1(i)
  up1(i)
  lo2(i)
  up2(i)
  sat1(i)   "maximum H"
  sat2(i)   "maximum H"
   feas(i)  "feasiblity constraint"
   obj       "objective function"
;

* variables bounds

awf.lo(i)=0.1;        awf.up(i)=1.;
radius.lo=1;       radius.up=5;
thick.lo(i)=0.2;      thick.up(i)=1.0;
currnt.lo(i)=2.0;      currnt.up(i)=6.0;
narm.lo(i)=300;        narm.up(i)=1500;
nfield.lo=60;        nfield.up=500;

*awf.l('1')=    0.389   ;   awf.l('2')=      0.264;  awf.l('3')=       0.252;  awf.l('4')=       0.259;  awf.l('5')=       0.286;
*radius.l=    2.636;
*thick.l('1')=  0.586   ;   thick.l('2')=    1.000;  thick.l('3')=     0.973;  thick.l('4')=     0.887;  thick.l('5')=     0.894;
*currnt.l('1')= 3.8952  ;   currnt.l('2')=   3.268;  currnt.l('3')=    3.760;  currnt.l('4')=    4.201;  currnt.l('5')=    4.356;
*narm.l('1')=   1247.459;   narm.l('2')=   895.391;  narm.l('3')=   1153.481;  narm.l('4')=   1207.726;  narm.l('5')=   1262.193;
*nfield.l=   82.320;

sat1(i)  ..   2.0*nfield*currnt(i)/(5.1416*radius-0.4292*thick(i))=l=maxh/100;
sat2(i)  ..   2.0*nfield*currnt(i)/(5.1416*radius-0.4292*thick(i))=g=minh/100;


feas(i) ..   radius=g=thick(i)+200*lgap*0.001;

up2(i) ..  1.0e-3*lmax*currnt(i)**2*narm(i)*nfield=g=(torque(i)*pi*pi*(radius+
           0.5*thick(i))/(2*mro*thick(i))+torque(i)*pi/mro+100*torque(i)*pi*lgap/(muo*(radius-thick(i)-0.1*lgap)));

lo2(i) ..  1.0e-3*lmin*currnt(i)**2*narm(i)*nfield=l=(torque(i)*pi*pi*(radius+
           0.5*thick(i))/(2*mro*thick(i))+torque(i)*pi/mro+100*torque(i)*pi*lgap/(muo*(radius-thick(i)-0.1*lgap)));




lo1(i) ..    (voltag*currnt(i)-p-2*currnt(i))*0.1-10*currnt(i)**2*0.1/awf(i)*2*resist*nfield*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*(radius-thick(i)))=l=10*currnt(i)**2*
             resist*narm(i)*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*
             (radius-thick(i)-lgap*0.1));


up1(i) ..    (voltag*currnt(i)-p-2*currnt(i))-10*currnt(i)**2/awf(i)*2*resist*nfield*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*(radius-thick(i)))=g=10*currnt(i)**2*
              resist*narm(i)*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*
             (radius-thick(i)-lgap*0.1));


maxm(i) ..
 ((torque(i)*pi**2*dsteel/currnt(i)**2*(2*radius*thick(i)-thick(i)**2)*(pi*(2*radius+thick(i))/(4*mro*thick(i))+
 1/(mro)+100*lgap/(muo*(radius-thick(i)-lgap*0.1))))

 +(torque(i)*pi**2*dsteel/currnt(i)**2*(radius-thick(i)-lgap*0.1)**2*(pi*(2*radius+thick(i))/(4*mro*thick(i))
 +1/(mro)+100*lgap/(muo*(radius-thick(i)-lgap*0.1))))
  +.02*dcopper/currnt(i)**2*(narm(i)*((1.0/((voltag*currnt(i)-p-2*currnt(i))-10*currnt(i)**2/awf(i)*2*resist*nfield*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*(radius-thick(i))))*10*currnt(i)**2*
             resist*narm(i)*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*
             (radius-thick(i)-lgap*0.1))))*((torque(i)*pi*(pi*(2*radius+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius-thick(i)-0.1*lgap))))+0.02*(radius-thick(i)-0.1*lgap)*narm(i)*nfield*currnt(i)**2)+nfield*awf(i)*(2*(torque(i)*
pi*(pi*(2*radius+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius-thick(i)-0.1*lgap))))+0.04*narm(i)*nfield*currnt(i)**2*(radius-thick(i)))))=l=maxmass*narm(i)*nfield;



minm(i) ..
 (((torque(i)*pi**2*dsteel/currnt(i)**2*(2*radius*thick(i)-thick(i)**2)*(pi*(2*radius+thick(i))/(4*mro*thick(i))+
 1/(mro)+100*lgap/(muo*(radius-thick(i)-lgap*0.1))))

 +(torque(i)*pi**2*dsteel/currnt(i)**2*(radius-thick(i)-lgap*0.1)**2*(pi*(2*radius+thick(i))/(4*mro*thick(i))
 +1/(mro)+100*lgap/(muo*(radius-thick(i)-lgap*0.1))))
  +.02*dcopper/currnt(i)**2*(narm(i)*((1.0/((voltag*currnt(i)-p-2*currnt(i))-10*currnt(i)**2/awf(i)*2*resist*nfield*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*(radius-thick(i))))*10*currnt(i)**2*
             resist*narm(i)*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*
             (radius-thick(i)-lgap*0.1))))*((torque(i)*pi*(pi*(2*radius+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius-thick(i)-0.1*lgap))))+0.02*(radius-thick(i)-0.1*lgap)*narm(i)*nfield*currnt(i)**2)+nfield*awf(i)*(2*(torque(i)*
pi*(pi*(2*radius+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius-thick(i)-0.1*lgap))))+0.04*narm(i)*nfield*currnt(i)**2*(radius-thick(i))))))=g=minmass*narm(i)*nfield;



mineff(i) .. p/(voltag * currnt(i))=g=mineta;

maxeff(i) .. p/(voltag * currnt(i))=l=1.0;


obj ..   narm.up('1')*totobj=e=sum(i,0.5*(narm.up(i)-p*narm.up(i)/(voltag * currnt(i)))+0.5*(narm.up(i)/
         (maxmass*nfield*narm(i))*((torque(i)*pi**2*dsteel/currnt(i)**2*(radius**2+0.01*lgap**2+0.2*thick(i)*lgap-0.2*radius*lgap)*(pi*(2*radius+thick(i))/
         (4*mro*thick(i))+1/(mro)+100*lgap/(muo*(radius-thick(i)-lgap*0.1))))

  +.02*dcopper/currnt(i)**2*(narm(i)*((1.0/((voltag*currnt(i)-p-2*currnt(i))-10*currnt(i)**2/awf(i)*2*resist*nfield*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))
             /(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/(mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/
             (currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*(radius-thick(i))))*10*currnt(i)**2*
             resist*narm(i)*(2*(torque(i)*pi*pi*(radius+0.5*thick(i))/(2*mro*thick(i)*currnt(i)**2*narm(i)*nfield)+torque(i)*pi/
             (mro*currnt(i)**2*narm(i)*nfield)+100*torque(i)*pi*lgap/(currnt(i)**2*narm(i)*nfield*muo*(radius-thick(i)-0.1*lgap)))+0.04*
             (radius-thick(i)-lgap*0.1))))*((torque(i)*pi*(pi*(2*radius+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius-thick(i)-0.1*lgap))))+0.02*(radius-thick(i)-0.1*lgap)*narm(i)*nfield*currnt(i)**2)+nfield*awf(i)*(2*(torque(i)*
pi*(pi*(2*radius+thick(i))/(4*mro*thick(i))+1/(mro)
+100*lgap/(muo*(radius-thick(i)-0.1*lgap))))+0.04*narm(i)*nfield*currnt(i)**2*(radius-thick(i)))))));


model motor /all/ ;
motor.optfile=1;
$onecho > baron.opt
epsr 0.0001
maxtime=1200000
nlpsol=4
nlpdolin=0
numsol=10
$offecho
option nlp=baron;
solve motor using nlp minimizing totobj;
display awf.l, radius.l,thick.l,currnt.l,narm.l,nfield.l;
