sets
   o    orders /0*4/,
   i  " performance domain"   /wc, ar,ns,tg /


parameters
* Marketing parameters
   Q    total market size /5/
   ap2  a2 polynomial coefficient for price part-worth       /-0.0017143/
   ap1  a1 polynomial coefficient for price part-worth       /-0.013509/
   ap0  a0 polynomial coefficient for price part-worth       / 1.0374/
   ev0  outside good (no-choice option) =exp(v0)                /1/
   cv   "variable cost"     /3/
   cf   "fixed cost"        /1/
* Engineering Parameters
    y1  "Gap between Base and Cover"                           /0.30  /
    y2  "Horizontal Distance between Spring and Pivot"         /1.10  /
    y3  "Aspect Ratio of Number (Length/Width)"                /1.29  /
    y6  "Maximum spring deflection"                            /.5  /
    y7  "Minimum distance of the supports from the centerline" /4.00  /
    y8  "Number of lbs that Number Length Spans"               /16.00 /
    y11 "Distance between top of the cover and window"         /1.13  /
    y12 "Length of Tick Mark+Gap to Number"                    /0.31  /
    y13 "Minimum vertical distance between supports"           /6.0/
    x5min   "Lower bound for x5"                               /0.125/
    x5max   "upper bound for x5"                               /12.0/
    x14min  "lower bound for x14"                              /8.5/
    x14max  "upper bound for x14"                              /14.0/
    x7      "variable x7 is fixed in this model"               /0.5/
    x10     "variable x10 is fixed in this model"              /0.5/
    x11     "variable x11 is fixed in this model"              /1.9/
    pi
 ;
scalars
*output
weight, ratio, number, gap, area;

pi= 2*arctan(inf);

table a(i,o) polynomial fitting coefficients
       4                3            2            1            0
wc     0          0.423844581   -4.286609981   14.144898    -15.067124
ar   34.8044        -132.2115     177.9438     -99.4869      19.2282
*pa   200.8852367  -992.4232052  1827.581129  -1486.439334  450.4112036
tg   3.938036738  -20.37017339  37.03985793  -27.24144964  6.563132511
ns    0            0.868461568  -4.69621128  8.592920728  -4.923720258
;


positive variables
  x1      " Length from Base to Force on Long Lever"
  x2      " Length from Force to Spring on Long Lever"
  x3      " Length from Base to Force on Short Lever"
  x4      " Length from Force to Joint on Short Lever "
  x6      "spring constant"
  x8      " Length of Rack "
  x9      " pitch diameter of the pinion"
  x12     " Dial Diameter "
  x13     " Cover Length "
  z(i)
  p        "price"
;

free variable
  profit " objective function"
;

* upper and lower bounds for variables
p.lo=10;       p.up=30;
x1.lo=0.125;   x1.up=12;
x2.lo=0.125;   x2.up=15;
x3.lo=0.125;   x3.up=12;
x4.lo=0.125;   x4.up=12;
x6.lo=10.0;    x6.up=200;
x8.lo=2.00;    x8.up=10;
x9.lo=0.25;    x9.up=3.0;
x12.lo=4.0;    x12.up=12;
x13.lo=8.5;    x13.up=14;

z.lo('wc')=2;     z.up('wc')=4.0;
*z.lo('pa')=1.0;   z.up('pa')=1.4;
z.lo('ar')=0.75;  z.up('ar')=1.33;
z.lo('tg')=0.63;  z.up('tg')=1.875;
z.lo('ns')=0.75;  z.up('ns')=1.75;

x1.l=2.407  ;
x2.l=10.116   ;
x3.l=3.790 ;
x4.l=3.906 ;
x6.l=103.951 ;
x8.l=4.616   ;
x9.l=0.265  ;
x12.l=10.232;
x13.l= 12.432  ;

z.l('wc')=2.367;
z.l('ar')=1.104;
z.l('tg')=1.358;
z.l('ns')=1.553;

p.l=26.097;



equations
*marketing constraints
  fobj
*engineering constraints
  x5lo,x5up            "bounds on x5"
  x14lo,x14up          "bounds on x14"
  wPerf                "weight capacity "
  arPerf               "aspect ratio"
  nsPerf               "number size"
  paPerf1,paPerf2      "platform area bounds"
  tgPerf               "tickmark gap"
  cst1,cst2            "Dial should be small enough to fit in the scale"
  cst3,cst4            "Long levers must fit in the scale"
  cst5                 "Joint position of the long and shorts levers"
  cst6,cst16           "scale stablity constraint"
  cst11,cst12          "Rack must fit inside the scale"
  cst13                "spring deflection"
  cst14,cst15          "dial should not interfere with supports on levers"
;

* joint position of short and long levers
cst5 .. x1*x4=l=x2*x3;
* bounds on x5
x5lo .. x1*x4=g=x3*x5min;
x5up .. x1*x4=l=x3*x5max;
* bounds on x14
x14lo .. 2*sqrt((x3*(x1+x2)/x1)**2-power(x7+(x13-2*y1)*(x2*x3-x1*x4)/(x1*(x3+x4)),2))+2*y1=g=x14min;
x14up .. 2*sqrt((x3*(x1+x2)/x1)**2-power(x7+(x13-2*y1)*(x2*x3-x1*x4)/(x1*(x3+x4)),2))+2*y1=l=x14max;
* weight capacity
wPerf  .. z('wc')=e=0.02*pi*x6*x9*x10*(x1+x2)/(x11*x1);
*aspect ratio
arPerf .. z('ar')*(2*sqrt((x3*(x1+x2)/x1)**2-power(x7+(x13-2*y1)*(x2*x3-x1*x4)/(x1*(x3+x4)),2))+2*y1)=e=x13;
*number size
nsPerf .. z('ns')=e=2*tan(0.01*y8*pi/z('wc'))*(.5*x12-y12)/(1.0+2.0/y3*tan(0.01*y8*pi/z('wc')));
*platform area
paPerf1 .. 100=l= x13*(2*sqrt((x3*(x1+x2)/x1)**2-power(x7+(x13-2*y1)*(x2*x3-x1*x4)/(x1*(x3+x4)),2))+2*y1);
paPerf2 .. 140=g= x13*(2*sqrt((x3*(x1+x2)/x1)**2-power(x7+(x13-2*y1)*(x2*x3-x1*x4)/(x1*(x3+x4)),2))+2*y1);

*tickmark gap
tgPerf .. z('tg')=e= 0.1*pi*x12/z('wc');
* dial should fit within the scale
cst1 .. x12=l=2*sqrt((x3*(x1+x2)/x1)**2-power(x7+(x13-2*y1)*(x2*x3-x1*x4)/(x1*(x3+x4)),2));
cst2 .. x12=l=x13-2*y1-x7-y2;
* long levers should fit within the scale
cst3 .. x1+x2=l=sqrt(power(x13-2*y1-x7,2)+(x3*(x1+x2)/x1)**2-power(x7+(x13-2*y1)*(x2*x3-x1*x4)/(x1*(x3+x4)),2));
cst4 .. x1+x2=g=sqrt(power(x13-2*y1-x7,2)+((x1+x2)*y7/x2)**2);
* scale stability
cst6 .. (x2*x3-x1*x4)/(x3*(x1+x2))*sqrt((x1+x2)**2-power(x13-2*y1-x7,2))+x4*sqrt(1-power(((x2-x1*x4/x3)/(x1+x2)*(x13-2*y1-x7)+x7)/(x3+x4),2))=g=y7;
cst16 .. (x13-2*y1)*(x1+x2)*(x3+x4)-x3*(x1+x2)*(x13-2*y1-x7)-x3*x7*(x1+x2)=g=y13*(x1+x2)*(x3+x4);
* rack must fit within the scale
cst11 .. x8+x7+y2+x11=l=x13-2*y1;
cst12..  x8=g=x13-2*y1-.5*x12-x7-y2-x10;
* spring deflection
cst13.. y6=g=2*pi*x9*x10/x11;
* dial should not intefere with support positions on levers
cst14.. 0.5*x12=l=sqrt(power(x13-2*y1-.5*x12-x7,2)+x2**2-2*(x13-2*y1-.5*x12-x7)*x2*(x13-2*y1-x7)/(x1+x2));
cst15.. 0.5*x12=l=sqrt(power((x2-x1*x4/x3)/(x1+x2)*sqrt((x1+x2)**2-power(x13-2*y1-x7,2))+x4*sqrt(1-power((((x2-x1*x4/x3)/(x1
        +x2)*(x13-2*y1-x7)+x7)/(x3+x4)),2)),2)+power(x13-2*y1-0.5*x12-x3*(((x2-x1*x4/x3)/(x1+x2)*(x13-2*y1-x7)+x7)/(x3+x4)),2));

fobj .. profit=e=Q*(exp(sum(i,sum(o,a(i,o)*power(z(i),ord(o)-1)))+ap2*sqr(p)+ap1*p+ap0)/
                (1+exp(sum(i,sum(o,a(i,o)*power(z(i),ord(o)-1)))+ap2*sqr(p)+ap1*p+ap0)))
                 *(p-cv)-cf;

model weightscale /all/;
option nlp=conopt;

solve weightscale using nlp maximizing profit;


display z.l, p.l;